@@ -7,7 +7,7 @@
 ###############################################################################
 
 """
-Editra Buisness Model Library: FileObjectImpl
+Editra Business Model Library: FileObjectImpl
 
 Implementation of a file object interface class. Objects and methods inside
 of this library expect a file object that derives from this interface.
@@ -15,14 +15,16 @@ of this library expect a file object that derives from this interface.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: fileimpl.py 61040 2009-06-13 08:16:04Z CJP $"
-__revision__ = "$Revision: 61040 $"
+__svnid__ = "$Id: fileimpl.py 65714 2010-10-01 19:15:39Z CJP $"
+__revision__ = "$Revision: 65714 $"
 
 #--------------------------------------------------------------------------#
 # Imports
 import os
+import sys
 
-# Editra Buisness Model Imports
+# Editra Business Model Imports
+import txtutil
 import fileutil
 
 #--------------------------------------------------------------------------#
@@ -87,6 +89,16 @@ class FileObjectImpl(object):
             self.open = True
             return True
 
+    def Exists(self):
+        """Does the file exist on disk?
+        @return: bool
+
+        """
+        if self._path:
+            return fileutil.PathExists(self._path)
+        else:
+            return False
+
     def GetExtension(self):
         """Get the files extension if it has one else simply return the
         filename minus the path.
@@ -101,11 +113,18 @@ class FileObjectImpl(object):
         return self._handle
 
     def GetLastError(self):
-        """Return the last error that occured when using this file
+        """Return the last error that occurred when using this file
         @return: err traceback or None
 
         """
-        return unicode(self.last_err).replace("u'", "'")
+        errstr = u"None"
+        if self.last_err:
+            if not txtutil.IsUnicode(self.last_err):
+                errstr = unicode(self.last_err, sys.getfilesystemencoding())
+                errstr = errstr.replace("u'", "'")
+            else:
+                errstr = self.last_err
+        return errstr
 
     def GetModtime(self):
         """Get the timestamp of this files last modification"""
