@@ -44,8 +44,8 @@ that require a sandwich like layout.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ctrlbox.py 61789 2009-08-30 17:52:11Z CJP $"
-__revision__ = "$Revision: 61789 $"
+__svnid__ = "$Id: ctrlbox.py 65202 2010-08-06 15:49:23Z CJP $"
+__revision__ = "$Revision: 65202 $"
 
 __all__ = ["ControlBox", "CTRLBOX_NAME_STR",
 
@@ -117,7 +117,7 @@ EVT_SEGMENT_CLOSE = wx.PyEventBinder(edEVT_SEGMENT_CLOSE, 1)
 class SegmentBarEvent(wx.PyCommandEvent):
     """SegmentBar Button Event"""
     def __init__(self, etype, id=0):
-        wx.PyCommandEvent.__init__(self, etype, id)
+        super(SegmentBarEvent, self).__init__(etype, id)
 
         # Attributes
         self.notify = wx.NotifyEvent(etype, id)
@@ -170,7 +170,7 @@ class ControlBox(wx.PyPanel):
                  pos=wx.DefaultPosition, size=wx.DefaultSize,
                  style=wx.TAB_TRAVERSAL|wx.NO_BORDER,
                  name=CTRLBOX_NAME_STR):
-        wx.PyPanel.__init__(self, parent, id, pos, size, style, name)
+        super(ControlBox, self).__init__(parent, id, pos, size, style, name)
 
         # Attributes
         self._sizer = wx.BoxSizer(wx.VERTICAL)
@@ -207,6 +207,7 @@ class ControlBox(wx.PyPanel):
         already exist.
         @keyword pos: wx.TOP (default) or wx.BOTTOM
         @postcondition: A top aligned L{ControlBar} is created.
+        @return: ControlBar
 
         """
         cbar = self.GetControlBar(pos)
@@ -215,6 +216,7 @@ class ControlBox(wx.PyPanel):
                               style=CTRLBAR_STYLE_GRADIENT)
 
             self.SetControlBar(cbar, pos)
+        return cbar
 
     def GetControlBar(self, pos=wx.TOP):
         """Get the L{ControlBar} used by this window
@@ -334,8 +336,8 @@ class ControlBar(wx.PyPanel):
                  pos=wx.DefaultPosition, size=wx.DefaultSize,
                  style=CTRLBAR_STYLE_DEFAULT,
                  name=CTRLBAR_NAME_STR):
-        wx.PyPanel.__init__(self, parent, id, pos, size,
-                            wx.TAB_TRAVERSAL|wx.NO_BORDER, name)
+        super(ControlBar, self).__init__(parent, id, pos, size,
+                                         wx.TAB_TRAVERSAL|wx.NO_BORDER, name)
 
         # Attributes
         self._style = style
@@ -539,7 +541,7 @@ class SegmentBar(ControlBar):
                  pos=wx.DefaultPosition, size=wx.DefaultSize,
                  style=CTRLBAR_STYLE_DEFAULT,
                  name=SEGBAR_NAME_STR):
-        ControlBar.__init__(self, parent, id, pos, size, style, name)
+        super(SegmentBar, self).__init__(parent, id, pos, size, style, name)
 
         # Attributes
         self._buttons = list()
@@ -603,6 +605,8 @@ class SegmentBar(ControlBar):
         dc.DrawBitmap(bmp, bpos[0], bpos[1], bmp.GetMask() != None)
 
         if draw_label:
+            lcolor = wx.SystemSettings.GetColour(wx.SYS_COLOUR_WINDOWTEXT)
+            dc.SetTextForeground(lcolor)
             twidth, theight = button['lsize']
             typos = height - theight - 2
             trect = wx.Rect(xpos, typos, self._segsize[0], theight + 3)
