@@ -73,8 +73,8 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: platebtn.py 63496 2010-02-16 06:47:55Z RD $"
-__revision__ = "$Revision: 63496 $"
+__svnid__ = "$Id: platebtn.py 65202 2010-08-06 15:49:23Z CJP $"
+__revision__ = "$Revision: 65202 $"
 
 __all__ = ["PlateButton",
            "PLATE_NORMAL", "PLATE_PRESSED", "PLATE_HIGHLIGHT", 
@@ -129,8 +129,9 @@ class PlateButton(wx.PyControl):
         @keyword style: Button style
 
         """
-        wx.PyControl.__init__(self, parent, id, pos, size,
-                              wx.BORDER_NONE|wx.TRANSPARENT_WINDOW, name=name)
+        super(PlateButton, self).__init__(parent, id, pos, size,
+                                          wx.BORDER_NONE|wx.TRANSPARENT_WINDOW,
+                                          name=name)
 
         # Attributes
         self.InheritAttributes()
