@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 64591 2010-06-15 04:00:50Z CJP $"
-__revision__ = "$Revision: 64591 $"
+__svnid__ = "$Id: ed_pages.py 65790 2010-10-10 19:47:11Z CJP $"
+__revision__ = "$Revision: 65790 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -61,7 +61,8 @@ class EdPages(aui.AuiNotebook):
                 aui.AUI_NB_SMART_TABS | \
                 aui.AUI_NB_USE_IMAGES_DROPDOWN | \
                 aui.AUI_NB_TAB_EXTERNAL_MOVE | \
-                aui.AUI_NB_TAB_FIXED_WIDTH
+                aui.AUI_NB_TAB_FIXED_WIDTH | \
+                aui.AUI_NB_ORDER_BY_ACCESS
         if wx.Platform == '__WXMAC__':
             style |= aui.AUI_NB_CLOSE_ON_TAB_LEFT
         aui.AuiNotebook.__init__(self, parent, id_num, agwStyle=style)
@@ -81,7 +82,7 @@ class EdPages(aui.AuiNotebook):
         self.frame = self.GetTopLevelParent() # MainWindow
         self._index = dict()          # image list index
         self._ses_load = False
-        self._menu = None
+        self._menu = ebmlib.ContextMenuManager()
 
         # Setup Tab Navigator
         ed_icon = ed_glob.CONFIG['SYSPIX_DIR'] + u"editra.png"
@@ -434,17 +435,13 @@ class EdPages(aui.AuiNotebook):
         @param evt: wx.MenuEvent
 
         """
-        if self._menu is not None:
-            ctab = self.GetCurrentPage()
-            handler = self._menu.GetHandler(evt.GetId())
-            if handler is not None:
-                handler(ctab, evt)
-            elif ctab is not None:
-                ctab.OnTabMenu(evt)
-            else:
-                evt.Skip()
+        ctab = self.GetCurrentPage()
+        handler = self._menu.GetHandler(evt.GetId())
+        if handler is not None:
+            handler(ctab, evt)
+        elif ctab is not None:
+            ctab.OnTabMenu(evt)
         else:
-            self.LOG("[ed_pages][warn] OnMenu: Menu is None!")
             evt.Skip()
 
     def OnDocPointerRequest(self, args):
@@ -454,12 +451,11 @@ class EdPages(aui.AuiNotebook):
 
         """
         sender, path = args
-        if sender != self:
-            for buf in self.GetTextControls():
-                if buf.GetFileName() == path:
-                    return buf
-
-        return ed_msg.NullValue()
+        for buf in self.GetTextControls():
+            if buf.GetFileName() == path:
+                return buf
+        else:
+            return ed_msg.NullValue()
 
     def OnTabLeftDClick(self, evt):
         """Handle left double clicks and open new tab when in empty area.
@@ -538,8 +534,7 @@ class EdPages(aui.AuiNotebook):
 
     def OnTabMenu(self, evt):
         """Show the tab context menu"""
-        if self._menu is not None:
-            self._menu.Clear()
+        self._menu.Clear()
 
         # Construct the menu
         tab = evt.GetSelection()
@@ -548,17 +543,17 @@ class EdPages(aui.AuiNotebook):
 
         ctab = self.GetCurrentPage()
         if ctab is not None:
-            if self._menu is None:
-                self._menu = ebmlib.ContextMenuManager()
             menu = ctab.GetTabMenu()
+            if menu is None:
+                return # Tab has no menu
+
             self._menu.SetMenu(menu)
             self._menu.SetUserData("page", ctab)
 
             # Allow clients to customize the menu prior to showing it
             ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_TABMENU, self._menu)
 
-        # Show the menu
-        if self._menu is not None:
+            # Show the menu
             self.PopupMenu(self._menu.Menu)
 
     def OnThemeChanged(self, msg):
@@ -1152,6 +1147,9 @@ class EdPages(aui.AuiNotebook):
                                            SIMULATED_EVT_ID)
                 evt.SetSelection(idx)
                 self.OnPageClosed(evt)
+        except Exception:
+            # TODO: workaround for crash in base on destruction
+            pass
         finally:
             frame.Thaw()
 
