@@ -14,8 +14,8 @@ Shelf plugin and control implementation
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_shelf.py 64553 2010-06-10 13:17:16Z CJP $"
-__revision__ = "$Revision: 64553 $"
+__svnid__ = "$Id: ed_shelf.py 65567 2010-09-18 22:43:41Z CJP $"
+__revision__ = "$Revision: 65567 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -353,12 +353,10 @@ class EdShelfDelegate(object):
 
         """
         rval = list()
-        if self._shelf is None:
-            return rval
-
-        for page in xrange(self._shelf.GetPageCount()):
-            rval.append(re.sub(PGNUM_PAT, u'', 
-                        self._shelf.GetPageText(page), 1))
+        if self._shelf is not None:
+            for page in xrange(self._shelf.GetPageCount()):
+                rval.append(re.sub(PGNUM_PAT, u'', 
+                            self._shelf.GetPageText(page), 1))
         return rval
 
     def GetMenu(self):
@@ -401,7 +399,7 @@ class EdShelfDelegate(object):
 
     def GetWindow(self):
         """Return reference to the Shelfs window component
-        @return: FlatnoteBook
+        @return: AuiNotebook
 
         """
         return self._shelf
