@@ -20,8 +20,8 @@ U{http://editra.org/?page=docs&doc=ess_spec}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 62952 2009-12-20 02:01:47Z CJP $"
-__revision__ = "$Revision: 62952 $"
+__svnid__ = "$Id: ed_style.py 65733 2010-10-02 22:45:51Z CJP $"
+__revision__ = "$Revision: 65733 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -121,6 +121,15 @@ class StyleItem(object):
         style_str = u",".join(style_str)
         return style_str.rstrip(u",")
 
+    def Clone(self):
+        """Make and return a copy of this object"""
+        nitem = StyleItem(self.fore, self.back,
+                          self.face, self.size,
+                          self._exattr)
+        if self.null:
+            nitem.Nullify()
+        return nitem
+        
     #---- Get Functions ----#
     def GetAsList(self):
         """Returns a list of attr:value strings
@@ -381,7 +390,7 @@ class StyleMgr(object):
         """
         sty_dict = dict()
         for key in DEF_STYLE_DICT.keys():
-            if key in ('select_style', 'whitespace_style'):
+            if key in ('select_style',):
                 sty_dict[key] = NullStyleItem()
             else:
                 sty_dict[key] = StyleItem("#000000", "#FFFFFF",
@@ -511,7 +520,8 @@ class StyleMgr(object):
 
         """
         if self.HasNamedStyle(name):
-            item = StyleMgr.STYLES[self.style_set][name]
+            scheme = self.GetStyleSet()
+            item = scheme[name]
 
             # Set font value if need be
             ival = unicode(item)
@@ -661,6 +671,15 @@ class StyleMgr(object):
                     style_set[tag].SetBack(default.GetBack())
                 if not style_set[tag].GetSize():
                     style_set[tag].SetSize(default.GetSize())
+
+            # Now need to pack in undefined styles that are part of
+            # the standard set.
+            for tag in DEF_STYLE_DICT.keys():
+                if tag not in style_set:
+                    if tag == 'select_style':
+                        style_set[tag] = NullStyleItem()
+                    else:
+                        style_set[tag] = default.Clone()
         else:
             pass
         return style_set
@@ -727,6 +746,7 @@ class StyleMgr(object):
                 style_dict[tag] = value
 
         # Validate leaf values and format into style string
+        rdict = dict()
         for style_def in style_dict:
             if not style_def[0][0].isalpha():
                 self.LOG("[ed_style][err] The style def %s is not a "
@@ -793,9 +813,9 @@ class StyleMgr(object):
                     value = style_str.strip(u",")
                     if isinstance(value, basestring):
                         new_item.SetAttrFromStr(value)
-                    style_dict[style_def] = new_item
+                    rdict[style_def] = new_item
 
-        return style_dict
+        return rdict
 
     def SetGlobalFont(self, fonttag, fontface, size=-1):
         """Sets one of the fonts in the global font set by tag
@@ -860,6 +880,7 @@ class StyleMgr(object):
             for style in style_dict.values():
                 if not isinstance(style, StyleItem):
                     self.LOG("[ed_style][err] Invalid data in style dictionary")
+                    self.style_set = 'default'
                     return False
 
             self.style_set = name
@@ -871,7 +892,7 @@ class StyleMgr(object):
             # Set any undefined styles to match the default_style
             for tag, item in defaultd.iteritems():
                 if tag not in style_dict:
-                    if tag in ['select_style', 'whitespace_style']:
+                    if tag in ('select_style',):
                         style_dict[tag] = NullStyleItem()
                     else:
                         style_dict[tag] = style_dict['default_style']
@@ -968,11 +989,13 @@ class StyleMgr(object):
         self.SetSelBackground(True, sback)
 
         wspace = self.GetItemByName('whitespace_style')
-        if not wspace.IsNull():
-            self.SetWhitespaceBackground(True, wspace.GetBack())
-            self.SetWhitespaceForeground(True, wspace.GetFore())
+        self.SetWhitespaceBackground(True, wspace.GetBack())
+        self.SetWhitespaceForeground(True, wspace.GetFore())
 
-        self.SetCaretForeground(self.GetDefaultForeColour())
+        default_fore = self.GetDefaultForeColour()
+        edge_colour = self.GetItemByName('edge_style')
+        self.SetEdgeColour(edge_colour.GetFore())
+        self.SetCaretForeground(default_fore)
         self.SetCaretLineBack(self.GetItemByName('caret_line').GetBack())
         self.Colourise(0, -1)
 
@@ -1011,6 +1034,7 @@ DEF_STYLE_DICT = \
          'directive_style' : StyleItem("#0000FF", face="%(secondary)s",
                                        ex=["bold",]),
          'dockey_style' : StyleItem("#0000FF"),
+         'edge_style'   : StyleItem(), # inherit from default
          'error_style' : StyleItem("#DD0101", face="%(secondary)s",
                                     ex=["bold",]),
          'foldmargin_style' : StyleItem(back="#D1D1D1"),
