@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 63591 2010-03-01 00:12:30Z CJP $"
-__revision__ = "$Revision: 63591 $"
+__svnid__ = "$Id: prefdlg.py 65770 2010-10-05 14:52:16Z CJP $"
+__revision__ = "$Revision: 65770 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -74,7 +74,7 @@ def MakeThemeTool(tool_id):
 
 class PreferencesPanelBase(object):
     def __init__(self):
-        object.__init__(self)
+        super(PreferencesPanelBase, self).__init__()
 
         # Attributes
         self._layout_done = False
@@ -102,8 +102,9 @@ class PreferencesDialog(wx.Frame):
         @param id_: The id of this window
 
         """
-        wx.Frame.__init__(self, parent, id_,
-                          _("Preferences - Editra"), style=style)
+        super(PreferencesDialog, self).__init__(parent, id_,
+                                                _("Preferences - Editra"),
+                                                style=style)
         util.SetWindowIcon(self)
 
         # Extra Styles
@@ -177,9 +178,9 @@ class PrefTools(eclib.SegmentBook):
                changed the toolbook icons cannont be updated instantly.
 
         """
-        eclib.SegmentBook.__init__(self, parent, wx.ID_ANY,
-                                       style=eclib.SEGBOOK_STYLE_LABELS|\
-                                             eclib.SEGBOOK_STYLE_NO_DIVIDERS)
+        super(PrefTools, self).__init__(parent, wx.ID_ANY,
+                                        style=eclib.SEGBOOK_STYLE_LABELS|\
+                                              eclib.SEGBOOK_STYLE_NO_DIVIDERS)
 
         # Attributes
         self._imglst = list()
@@ -370,7 +371,7 @@ class GeneralPanel(wx.Panel, PreferencesPanelBase):
 class GeneralStartupPanel(wx.Panel):
     """General Startup Settings"""
     def __init__(self, parent):
-        wx.Panel.__init__(self, parent)
+        super(GeneralStartupPanel, self).__init__(parent)
 
         # Attributes
 
@@ -446,7 +447,7 @@ class GeneralStartupPanel(wx.Panel):
 
 class GeneralFilePanel(wx.Panel):
     def __init__(self, parent):
-        wx.Panel.__init__(self, parent)
+        super(GeneralFilePanel, self).__init__(parent)
 
         # Attributes
         
@@ -702,7 +703,7 @@ class DocGenPanel(wx.Panel):
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
+        super(DocGenPanel, self).__init__(parent)
 
         # Layout
         self._DoLayout()
@@ -770,6 +771,10 @@ class DocGenPanel(wx.Panel):
         ww_cb = wx.CheckBox(self, ed_glob.ID_WORD_WRAP, _("Word Wrap"))
         ww_cb.SetValue(Profile_Get('WRAP'))
         ww_cb.SetToolTipString(_("Turn off for better performance"))
+        vs_cb = wx.CheckBox(self, ed_glob.ID_PREF_VIRT_SPACE,
+                            _("View Virtual Space After Last Line"))
+        vs_cb.SetValue(Profile_Get('VIEWVERTSPACE', default=False))
+        vs_cb.SetToolTipString(_("Adds extra scrolling room after last line"))
 
         # Font Options
         fnt = Profile_Get('FONT1', 'font', wx.Font(10, wx.FONTFAMILY_MODERN,
@@ -785,7 +790,7 @@ class DocGenPanel(wx.Panel):
                                   "regions when syntax highlighting is in use"))
 
         # Layout
-        sizer = wx.FlexGridSizer(19, 2, 5, 5)
+        sizer = wx.FlexGridSizer(20, 2, 5, 5)
         sizer.AddGrowableCol(1, 1)
         sizer.AddMany([((10, 10), 0), ((10, 10), 0),
                        (wx.StaticText(self, label=_("Format") + u": "),
@@ -802,6 +807,7 @@ class DocGenPanel(wx.Panel):
                        ((5, 5), 0), (sln_cb, 0),
                        ((5, 5), 0), (sws_cb, 0),
                        ((5, 5), 0), (ww_cb, 0),
+                       ((5, 5), 0), (vs_cb, 0),
                        ((10, 10), 0), ((10, 10), 0),
                        (wx.StaticText(self, label=_("Primary Font") + u": "),
                         0, wx.ALIGN_CENTER_VERTICAL),
@@ -844,7 +850,7 @@ class DocGenPanel(wx.Panel):
         """
         # XXX Why when running on windows this and other imports randomly
         #     become None. I have been unable to reproduce this behavior myself
-        #     but have recieved enough error reports about it to beleive it.
+        #     but have received enough error reports about it to believe it.
         #     If they were actually NoneTypes the dialog would not be able to
         #     be shown so this is very strange!!
         global ed_glob
@@ -857,7 +863,8 @@ class DocGenPanel(wx.Panel):
                     ed_glob.ID_PREF_AALIAS, ed_glob.ID_SHOW_EOL,
                     ed_glob.ID_SHOW_LN, ed_glob.ID_SHOW_WS,
                     ed_glob.ID_WORD_WRAP, ed_glob.ID_PREF_AALIAS,
-                    ed_glob.ID_PREF_INDENTW, ed_glob.ID_PREF_AUTOTRIM ]:
+                    ed_glob.ID_PREF_INDENTW, ed_glob.ID_PREF_AUTOTRIM,
+                    ed_glob.ID_PREF_VIRT_SPACE ]:
 
             e_value = evt.GetEventObject().GetValue()
             if e_id == ed_glob.ID_EOL_MODE:
@@ -865,7 +872,7 @@ class DocGenPanel(wx.Panel):
 
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_value)
 
-            # Do updates for everything but text encoding
+            # Do updates for everything but autotrim whitespace
             if e_id not in (ed_glob.ID_PREF_AUTOTRIM, ):
                 wx.CallLater(25, DoUpdates)
         else:
@@ -884,7 +891,7 @@ class DocCodePanel(wx.Panel):
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
+        super(DocCodePanel, self).__init__(parent)
 
         # Layout
         self._DoLayout()
@@ -921,7 +928,7 @@ class DocCodePanel(wx.Panel):
         edge_cb = wx.CheckBox(self, ed_glob.ID_SHOW_EDGE, _("Edge Guide"))
         edge_cb.SetValue(Profile_Get('SHOW_EDGE'))
         edge_sp = wx.SpinCtrl(self, ed_glob.ID_PREF_EDGE,
-                              Profile_Get('EDGE', 'str'), min=0, max=120)
+                              Profile_Get('EDGE', 'str'), min=0, max=160)
         edge_sp.SetToolTipString(_("Guide Column"))
         edge_col = wx.BoxSizer(wx.HORIZONTAL)
         edge_col.AddMany([(edge_cb, 0, wx.ALIGN_CENTER_VERTICAL),
@@ -1051,7 +1058,7 @@ class DocSyntaxPanel(wx.Panel):
         @param parent: parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
+        super(DocSyntaxPanel, self).__init__(parent)
 
         # Attributes
         self._elist = ExtListCtrl(self)
@@ -1355,7 +1362,7 @@ ID_PASSWORD = wx.NewId()
 class NetConfigPage(wx.Panel):
     """Configuration page for network and proxy settings"""
     def __init__(self, parent):
-        wx.Panel.__init__(self, parent)
+        super(NetConfigPage, self).__init__(parent)
 
         # Layout
         self._DoLayout()
@@ -1484,7 +1491,7 @@ class UpdatePage(wx.Panel):
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
+        super(UpdatePage, self).__init__(parent)
 
         # Layout
         self._DoLayout()
@@ -1599,7 +1606,7 @@ class AdvancedPanel(wx.Panel):
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent, style=wx.BORDER_SUNKEN)
+        super(AdvancedPanel, self).__init__(parent, style=wx.BORDER_SUNKEN)
 
         # Layout
         self._layout_done = False
@@ -1654,7 +1661,7 @@ class KeyBindingPanel(wx.Panel):
     """Keybinding configration options"""
     def __init__(self, parent):
         """Create the panel"""
-        wx.Panel.__init__(self, parent)
+        super(KeyBindingPanel, self).__init__(parent)
 
         # Attributes
         self.menub = wx.GetApp().GetActiveWindow().GetMenuBar()
@@ -2118,7 +2125,7 @@ class ExChoice(wx.Choice):
         if len(choices) and isinstance(choices[0], int):
             choices = [ unicode(choice) for choice in choices ]
 
-        wx.Choice.__init__(self, parent, cid, choices=choices)
+        super(ExChoice, self).__init__(parent, cid, choices=choices)
 
         if default != None and isinstance(default, basestring):
             self.SetStringSelection(default)
