@@ -18,8 +18,8 @@ AUTHOR: Cody Precord
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synglob.py 63255 2010-01-25 02:05:22Z CJP $"
-__revision__ = "$Revision: 63255 $"
+__svnid__ = "$Id: synglob.py 65461 2010-09-02 04:09:42Z CJP $"
+__revision__ = "$Revision: 65461 $"
 
 #-----------------------------------------------------------------------------#
 # Dependencies
@@ -39,10 +39,12 @@ FEATURE_STYLETEXT = u"StyleText"
 
 # Maps file types to syntax definitions
 LANG_MAP = {LANG_4GL    : (ID_LANG_4GL,       '_progress'),
+            LANG_DSP56K : (ID_LANG_DSP56K,    '_asm68k'),
             LANG_68K    : (ID_LANG_68K,       '_asm68k'),
             LANG_ADA    : (ID_LANG_ADA,       '_ada'),
             LANG_APACHE : (ID_LANG_APACHE,    '_apache'),
             LANG_AS     : (ID_LANG_AS,        '_actionscript'),
+            LANG_ASM    : (ID_LANG_ASM,       '_asm'),
             LANG_BASH   : (ID_LANG_BASH,      '_sh'),
             LANG_BATCH  : (ID_LANG_BATCH,     '_batch'),
             LANG_BOO    : (ID_LANG_BOO,       '_boo'),
@@ -88,9 +90,11 @@ LANG_MAP = {LANG_4GL    : (ID_LANG_4GL,       '_progress'),
             LANG_MSSQL  : (ID_LANG_MSSQL,  '_mssql'),
             LANG_NASM   : (ID_LANG_NASM,   '_nasm'),
             LANG_NEWLISP: (ID_LANG_NEWLISP,'_lisp'),
+            LANG_NONMEM : (ID_LANG_NONMEM, '_nonmem'),
             LANG_NSIS   : (ID_LANG_NSIS,   '_nsis'),
             LANG_OBJC   : (ID_LANG_OBJC,   '_cpp'),
             LANG_OCTAVE : (ID_LANG_OCTAVE, '_matlab'),
+            LANG_OOC    : (ID_LANG_OOC,    '_ooc'),
             LANG_PASCAL : (ID_LANG_PASCAL, '_pascal'),
             LANG_PERL   : (ID_LANG_PERL,   '_perl'),
             LANG_PHP    : (ID_LANG_PHP,    '_php'),
@@ -137,9 +141,11 @@ def GetDescriptionFromId(lang_id):
 
     """
     rval = LANG_TXT
-    for key, val in globals().iteritems():
+    # Guard against async code that may be modifying globals
+    globs = dict(globals())
+    for key, val in globs.iteritems():
         if val == lang_id and key.startswith('ID_LANG'):
-            rval = globals().get(key[3:], LANG_TXT)
+            rval = globs.get(key[3:], LANG_TXT)
             break
     return rval
 
@@ -152,9 +158,11 @@ def GetIdFromDescription(desc):
     """
     rval = ID_LANG_TXT
     desc = desc.lower()
-    for key, val in globals().iteritems():
+    # Guard against async code that may be modifying globals
+    globs = dict(globals())
+    for key, val in globs.iteritems():
         if isinstance(val, basestring) and \
            val.lower() == desc and key.startswith('LANG_'):
-            rval = globals().get(u"ID_" + key, ID_LANG_TXT)
+            rval = globs.get(u"ID_" + key, ID_LANG_TXT)
             break
     return rval
